California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 67 - EMERGENCY AND MEDICAL SERVICES. FUNDING. TELEPHONE SURCHAGE. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256587 | COALITION TO PRESERVE EMERGENCY CARE - SPONSORED BY FIREFIGHTERS, PARAMEDICS, DOCTORS, NURSES AND HEALTHCARE PROVIDERS - YES ON 67 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1242018 | AMERICAN COLLEGE OF EMERGENCY PHYSICIANS STATE CHAPTER OF CALIFORNIA, INC. INITIATIVE FUND (AKA CAL/ACEP) - YES ON 67 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1258201 | STOP THE PHONE TAX - NO ON 67, A COALITION OF SENIORS, TAXPAYERS, CONSUMERS, SMALL BUSINESSES AND TELECOMMUNICATIONS PROVIDERS | OPPOSE